@@ -4,12 +4,12 @@ use ockam_vault_core::{
     CURVE25519_SECRET_LENGTH,
 };
 
-pub fn compute_key_id_for_public_key(vault: &mut impl KeyIdVault) {
+pub async fn compute_key_id_for_public_key(vault: &mut impl KeyIdVault) {
     let public =
         decode("68858ea1ea4e1ade755df7fb6904056b291d9781eb5489932f46e32f12dd192a").unwrap();
     let public = PublicKey::new(public.to_vec());
 
-    let key_id = vault.compute_key_id_for_public_key(&public).unwrap();
+    let key_id = vault.compute_key_id_for_public_key(&public).await.unwrap();
 
     assert_eq!(
         key_id,
@@ -17,18 +17,18 @@ pub fn compute_key_id_for_public_key(vault: &mut impl KeyIdVault) {
     );
 }
 
-pub fn get_secret_by_key_id(vault: &mut (impl KeyIdVault + SecretVault)) {
+pub async fn get_secret_by_key_id(vault: &mut (impl KeyIdVault + SecretVault)) {
     let attributes = SecretAttributes::new(
         SecretType::Curve25519,
         SecretPersistence::Ephemeral,
         CURVE25519_SECRET_LENGTH,
     );
 
-    let secret = vault.secret_generate(attributes).unwrap();
-    let public = vault.secret_public_key_get(&secret).unwrap();
+    let secret = vault.secret_generate(attributes).await.unwrap();
+    let public = vault.secret_public_key_get(&secret).await.unwrap();
 
-    let key_id = vault.compute_key_id_for_public_key(&public).unwrap();
-    let secret2 = vault.get_secret_by_key_id(&key_id).unwrap();
+    let key_id = vault.compute_key_id_for_public_key(&public).await.unwrap();
+    let secret2 = vault.get_secret_by_key_id(&key_id).await.unwrap();
 
     assert_eq!(secret.index(), secret2.index());
 }
